var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
import { handleJson, handleText } from './clientError.js';
/**
 * BaseClient serves as the base class for API clients.
 * Provides basic functionalities for making HTTP requests to a server.
 */
export class BaseClient {
    /**
     * @param host - The server's address.
     * @param reqInit - Optional default request initializer.
     */
    constructor(host, reqInit = undefined) {
        this.host = host;
        this.reqInit = reqInit;
    }
    fetch(path, query, init) {
        return __awaiter(this, void 0, void 0, function* () {
            var _a;
            const req = Object.assign(Object.assign(Object.assign({}, this.reqInit), init), { headers: Object.assign(Object.assign({}, (_a = this.reqInit) === null || _a === void 0 ? void 0 : _a.headers), init === null || init === void 0 ? void 0 : init.headers) });
            let uri = this.getUri(path);
            uri = query ? `${uri}?${new URLSearchParams(query)}` : uri;
            return { uri, res: yield fetch(uri, req), req };
        });
    }
    get(path, query, init) {
        return this.method('get', path, query, init);
    }
    put(path, query, init) {
        return this.method('put', path, query, init);
    }
    delete(path, query, init) {
        return this.method('delete', path, query, init);
    }
    post(path, query, init) {
        return this.method('post', path, query, init);
    }
    text(path, query, init) {
        return __awaiter(this, void 0, void 0, function* () {
            const result = yield this.fetch(path, query, init);
            return this.handleText(result);
        });
    }
    json(path, query, init) {
        return __awaiter(this, void 0, void 0, function* () {
            const result = yield this.fetch(path, query, init);
            return this.handleJson(result);
        });
    }
    method(method, path, query, init) {
        return __awaiter(this, void 0, void 0, function* () {
            const result = yield this.fetch(path, query, Object.assign(Object.assign({}, init), { method }));
            return result.res;
        });
    }
    /**
     * Constructs a URI path by joining URI components.
     * @param paths - Paths to encode and join.
     * @returns encoded URI path.
     */
    getPath(...paths) {
        return paths.map(encodeURIComponent).join('/');
    }
    /**
     * Constructs a URI by appending a path to the host.
     * @param path - The path to append to the host.
     * @returns URI string.
     */
    getUri(path) {
        return `${this.host}/${path}`;
    }
    /**
     * Handles text responses from the server.
     * @param req - The request object.
     * @param res - The response object.
     * @param uri - The request URI.
     * @returns Promise that resolves with the text data.
     */
    handleText({ req, res, uri, }) {
        return handleText.bind(this)(req, res, uri);
    }
    /**
     * Handles JSON responses from the server.
     * @param req - The request object.
     * @param res - The response object.
     * @param uri - The request URI.
     * @returns Promise that resolves with the JSON data.
     */
    handleJson({ req, res, uri, }) {
        const handle = (handleJson);
        return handle.bind(this)(req, res, uri);
    }
}
//# sourceMappingURL=baseClient.js.map