var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
/**
 * Represents a client-side error.
 */
class ClientError extends Error {
    /**
     * Constructs a ClientError.
     * @param message - The error message.
     * @param client - The BaseClient that generated the error.
     * @param response - The server's response.
     * @param request - The original request.
     * @param uri - The URI to which the request was sent.
     */
    constructor(message, client, response, request, uri) {
        super(message);
        this.client = client;
        this.response = response;
        this.request = request;
        this.uri = uri;
    }
}
/**
 * Type guard for ClientError.
 * @param object - The object to check.
 * @returns True if the object is a ClientError; otherwise, false.
 */
// eslint-disable-next-line @typescript-eslint/no-explicit-any
export function isClientError(object) {
    return (object instanceof ClientError ||
        ('client' in object &&
            'message' in object &&
            'host' in object.client &&
            'subdomain' in object.client &&
            'response' in object &&
            'status' in object.response &&
            !isNaN(object.response.status)));
}
/**
 * Fetches a resource as text.
 * @param req - The request object.
 * @param res - The response object.
 * @param uri - The URI to fetch from.
 * @throws ClientError - If the response is not ok.
 * @returns The fetched text.
 */
export function handleText(req, res, uri) {
    return __awaiter(this, void 0, void 0, function* () {
        const text = yield res.text();
        if (res.ok) {
            return text;
        }
        else {
            throw new ClientError(text, this, res, req, uri);
        }
    });
}
/**
 * Fetches a resource as JSON.
 * @param req - The request object.
 * @param res - The response object.
 * @param uri - The URI to fetch from.
 * @throws ClientError - If the response is not ok.
 * @returns The fetched JSON data.
 */
export function handleJson(req, res, uri) {
    return __awaiter(this, void 0, void 0, function* () {
        if (res.ok) {
            return res.json();
        }
        else {
            throw new ClientError(yield res.text(), this, res, req, uri);
        }
    });
}
//# sourceMappingURL=clientError.js.map