import { BaseClient } from '../client/index.js';
import { ENDPOINT, HEADERS } from './constants.js';
export class LeavesClient extends BaseClient {
    constructor(subdomain, host, reqInit = undefined) {
        super(host, reqInit);
        this.subdomain = subdomain;
    }
    /**
     * @deprecated
     * Use the separate methods instead:
     *   `getStaticPage`
     *   `getStaticMetadata`
     *   `getStaticNav`
     *   `getStaticCssAndJsFiles`
     *   `getStaticSnippets`
     *   `getStaticOpenApiUrls`
     */
    getStaticProps(pagePath) {
        const path = this.getPath('client', 'page', this.subdomain, pagePath);
        return this.json(path);
    }
    getStaticPage(pagePath) {
        const path = this.getPath('client', 'page-data', this.subdomain, pagePath);
        return this.json(path);
    }
    getStaticMetadata() {
        const path = this.getPath('client', 'metadata', this.subdomain);
        return this.json(path);
    }
    getStaticNav() {
        const path = this.getPath('client', 'filtered-navigation', this.subdomain);
        return this.json(path);
    }
    getStaticCssAndJsFiles() {
        const path = this.getPath('client', 'assets', this.subdomain);
        return this.json(path);
    }
    getStaticSnippets() {
        const path = this.getPath('client', 'snippets', this.subdomain);
        return this.json(path);
    }
    getStaticOpenApiUrls(pagePath) {
        const path = this.getPath('client', 'openapi-urls', this.subdomain, pagePath);
        return this.json(path);
    }
    getHostingLocation() {
        const path = this.getPath('client', 'hosting-location', this.subdomain);
        return this.text(path);
    }
    getSitemapPaths() {
        const path = this.getPath('client', 'sitemap-paths', this.subdomain);
        return this.json(path);
    }
    getLlmsTxt() {
        const path = this.getPath('client', 'llms-txt', this.subdomain);
        return this.json(path);
    }
    getLoginMetadata() {
        const path = this.getPath('client', 'login-metadata', this.subdomain);
        return this.json(path);
    }
    getNavigation() {
        const path = this.getPath('client', 'navigation', this.subdomain);
        return this.json(path);
    }
    getStaticRssFiles() {
        const path = this.getPath('client', 'rss', this.subdomain);
        return this.json(path);
    }
}
export const getLeavesClient = (subdomain, host = ENDPOINT, reqInit = { headers: HEADERS }) => new LeavesClient(subdomain, host, reqInit);
export default getLeavesClient;
//# sourceMappingURL=leavesClient.js.map